<?php
/* References
 * https://github.com/chipbennett/oenology/blob/master/functions/options.php#L84
 * http://www.chipbennett.net/2011/02/17/incorporating-the-settings-api-in-wordpress-themes/7/
 */
/* Add admin menu */
add_action( 'admin_menu', 'pm_vat_admin_menu' );
function pm_vat_admin_menu() {
	global $pm_vat_settings;
	
	// Create options page
	$pm_vat_settings = add_options_page(PM_VAT_PLUGIN_NAME.' Settings', PM_VAT_PLUGIN_NAME, 'manage_options', 'pm_vat_settings', 'pm_vat_options_page');
  	
  	// Load admin scripts when above page is called
  	add_action( 'load-'.$pm_vat_settings, 'pm_vat_adminscripts' );
}

// Enqueue admin scripts
function pm_vat_adminscripts() {
	global $pm_vat_settings;
	$screen = get_current_screen();
/*
	// Load contextual help
	if( $screen->id != $pm_vat_settings )
		return;

	// Remove default tabs
    $screen->remove_help_tabs();

	$screen->add_help_tab(array(
		'id' => 'pm-vat-help', // should be unique
		'title' => 'Special Intstruction',
		'content' => '<b>Yeah! Your help here</b>',
		// Use callback instead of 'content' 
		));
*/
	// Enqueue scripts and styles
	wp_enqueue_script( 'pm-vat-admin', PM_VAT_DIR.'modules/js/admin.js', array('jquery', 'wp-color-picker'), PM_VAT_VERSION, true );
	wp_enqueue_script( 'jquery-ui-accordion' );
	wp_localize_script( 'pm-vat-admin', 'pm_vat_object',
            array( 
				'nonce' => wp_create_nonce('pm_vat_options'),
				'is_admin' => is_admin(),
				'plugin_name' => PM_VAT_PLUGIN_NAME
            	)
            );
	wp_enqueue_style( 'pm-vat-admin', PM_VAT_DIR.'modules/css/admin.css', '', PM_VAT_VERSION, 'all' );
	wp_enqueue_style('wp-color-picker');
}

// WP Pointer Admin Tooltip - Make sure you use cookie to dismiss
add_action('admin_enqueue_scripts', 'pm_vat_enqueue_admin_scripts');
function pm_vat_enqueue_admin_scripts() {
    $dismissed = explode (',', get_user_meta (wp_get_current_user ()->ID, 'dismissed_wp_pointers', true));
    $not_in_array = !in_array ('pm_vat_settings_dismiss', $dismissed);

    if( $not_in_array ) {
	    wp_enqueue_style('wp-pointer');
	    wp_enqueue_script('wp-pointer');
	    //hook the pointer 
	    add_action('admin_print_footer_scripts', 'pm_vat_print_footer_scripts' );
	}
}
function pm_vat_print_footer_scripts() {
    $pointer_content = '<h3>'.PM_VAT_PLUGIN_NAME.'</h3>';
    $pointer_content .= '<p>Configure your settings here.</p>';
?>
   <script type="text/javascript">
   //<![CDATA[
   jQuery(document).ready( function($) {
    //jQuery selector to point to 
    $('#menu-settings').pointer({
        content: '<?php echo $pointer_content; ?>',
        position: 'top',
        close: function() {
            // This function is fired when you click the close button
            $.post (ajaxurl, {
		        pointer: 'pm_vat_settings_dismiss',
		        action: 'dismiss-wp-pointer'
		    });
        }
      }).pointer('open');
   });
   //]]>
   </script>
<?php
}

// Output the settings page
function pm_vat_options_page() {
	$tab = ( isset( $_GET['tab'] )  ? $_GET['tab'] : 'ads' );
	$settings_section = 'pm_vat_settings_'.$tab.'_tab';
	?>
	<div class="wrap">
		<h2><?php echo PM_VAT_PLUGIN_NAME; ?> Settings</h2>
		<?php settings_errors( 'pm_vat_options' ); ?>
		<?php pm_vat_settings_page_tabs(); ?>

		<form action='options.php' method='post'>
			<?php 
			// Call functions to build form
			settings_fields( 'pm_vat_options' );
			//do_settings_sections( 'pm_vat_settings' );
			do_settings_sections( $settings_section );

			// Update settings based on tab			
			?>
			<p class="submit">
			<?php
			submit_button( 'Save Settings', 'primary', 'pm_vat_options[submit-'.$tab.']', false, array( 'id' => 'submit-'.$tab ) );
			submit_button( 'Reset', 'secondary', 'pm_vat_option[reset-'.$tab.']', false, array( 'id' => 'reset-'.$tab ) );
			?></p>
		</form>
	</div>
	<?php
}

// Create tabs
function pm_vat_get_settings_page_tabs() {
	$tabs = array(
		'ads' => 'Videos & Ads',
		'adstyle' => 'Style',
		'misc' => 'Miscellaneous',
		);
	return $tabs;
}

// HTML Markup for tabs
function pm_vat_settings_page_tabs( $current = 'ads' ) {
	// Determind which tab to display
	if( isset( $_GET['tab'] ) ) :
		$current = $_GET['tab'];
	else:
		$current = 'ads';
	endif;

	// Get list of tabs
	$tabs = pm_vat_get_settings_page_tabs();
	$links = array();

	// Create links for each tab
	foreach ($tabs as $tab => $name) :
		if( $tab == $current ) :
			$links[] = '<a class="nav-tab nav-tab-active" href="?page=pm_vat_settings&tab='.$tab.'">'.$name.'</a>';
		else :
			$links[] = '<a class="nav-tab" href="?page=pm_vat_settings&tab='.$tab.'">'.$name.'</a>';
		endif;
	endforeach;

	echo '<h2 class="nav-tab-wrapper">';
	foreach ( $links as $link ) {
		echo $link;
	}
	echo '</h2>';
}

// Register settings
add_action( 'admin_init', 'pm_vat_initialize_settings' );
function pm_vat_initialize_settings() {
	// Register fields
	register_setting( 
		'pm_vat_options',
		'pm_vat_options', 
		'pm_vat_validate_options' );

	// Add settings sections
	pm_vat_add_settings_sections();
	//add_settings_section( 'one', 'One Section', 'pm_vat_one_section_callback', 'pm_vat_settings' );

	// Add settings fields
	pm_vat_add_settings_fields();
	//add_settings_field( 'textfield', 'Text Field', 'pm_vat_textfield_field_callback', 'pm_vat_settings', 'one' );
}

/*---------------
 Sections
 ---------------*/
// Register multiple settings (called in admin_init)
function pm_vat_add_settings_sections() {
	// Array with settings identifiers
	$sects = array(
		'adsetup' => array(
			'id' => 'adsetup',
			'title' => 'Video',
			'page' => 'pm_vat_settings_ads_tab'
			),
		'boxstyle' => array(
			'id' => 'boxstyle',
			'title' => 'Box Style',
			'page' => 'pm_vat_settings_adstyle_tab'
			),
		'data' => array(
			'id' => 'data',
			'title' => 'Data Handling',
			'page' => 'pm_vat_settings_misc_tab'
			),
		);

	// Loop through each
	foreach ($sects as $s) {
		add_settings_section( 
			$s['id'].'_section',
			$s['title'].' Options',
			'pm_vat_'.$s['id'].'_section_callback',
			$s['page']
			);
	}
}

/*----------------
Sections callback
-----------------*/
// Section callback
function pm_vat_adsetup_section_callback() {
	echo '<p>Setup your video and its ads here.</p>';
}
function pm_vat_boxstyle_section_callback() {
}
function pm_vat_data_section_callback() {
}

/*------------------
Fields
------------------*/
// Register multiple fields (called in admin_init)
function pm_vat_add_settings_fields () {
	// Array with field info
	$fields = array(
		'adarray' => array(
			'id' => 'adarray',
			'title' => 'Videos',
			'page' => 'pm_vat_settings_ads_tab',
			'section' => 'adsetup_section'
			),
		'border' => array(
			'id' => 'border',
			'title' => 'Border options',
			'page' => 'pm_vat_settings_adstyle_tab',
			'section' => 'boxstyle_section'
			),
		'background' => array(
			'id' => 'background',
			'title' => 'Background color',
			'page' => 'pm_vat_settings_adstyle_tab',
			'section' => 'boxstyle_section'
			),
		'font' => array(
			'id' => 'font',
			'title' => 'Font options',
			'page' => 'pm_vat_settings_adstyle_tab',
			'section' => 'boxstyle_section'
			),
		'optsdata' => array(
			'id' => 'optsdata',
			'title' => 'Settings Data',
			'page' => 'pm_vat_settings_misc_tab',
			'section' => 'data_section'
			),
		);

	// Loop through each in array
	foreach ($fields as $f) {
		add_settings_field( 
			$f['id'],
			$f['title'],
			'pm_vat_'.$f['id'].'_field_callback',
			$f['page'],
			$f['section']
			);
	}
}

/*--------------------
Fields callback
--------------------*/
function pm_vat_adarray_field_callback() {
	$pm_vat_options = get_option('pm_vat_options');
	$videos = pm_isset_var($pm_vat_options, 'videos');

	$optionID = 'pm_vat_options';
	?>
	<button class="add_a_video" class="secondary-button">Add New Video</button>
	<div id='video_list'>
	<?php
	// Check for presence of videos option
	if( !empty( $videos ) ) {
		$saved_videos = new PmillVideoAdOptions( $videos );
		echo $saved_videos->pm_videoad_options();
	} else {
		$videoAdOptions = array(
			'1' => array(
				'count' => '1',
				'optkey' => 'videos',
				'videoname' => '',
				'ytvdoid' => '',
				'controls' => '0',
				'autoplay' => '0',
				'focusplay' => '1',
				'messages' => '',
				'pausetext' => '',
				'endtext' => '',
				'endscreen' => '',
				)
			);
		$buildVideoAd = new PmillVideoAdOptions( $videoAdOptions );
		echo $buildVideoAd->pm_videoad_options();
	}
	?>
	</div>
	<?php
}
function pm_vat_border_field_callback() {
	$pm_vat_opts = get_option( 'pm_vat_options' );
	$border_color = ( empty( $pm_vat_opts['stylearray']['border_color'] ) ) ? '' : stripslashes( $pm_vat_opts['stylearray']['border_color'] ) ;
	$border_width = ( empty( $pm_vat_opts['stylearray']['border_width'] ) ) ? '' : stripslashes( $pm_vat_opts['stylearray']['border_width'] ) ;
	$border_style = ( empty( $pm_vat_opts['stylearray']['border_style'] ) ) ? '' : stripslashes( $pm_vat_opts['stylearray']['border_style'] ) ;
	?>
	<table id="border-style-table">
		<thead>
			<tr>
				<th>Color</th>
				<th>Width (pixels)</th>
				<th>Style</th>
			</tr>
		</thead>
		<tbody>
			<tr>
				<td>
					<input type="text" name="pm_vat_options[border_color]" id="border_color" class="color-picker" value="<?php echo $border_color; ?>">
				</td>
				<td>
					<input type="text" name="pm_vat_options[border_width]" id="border_width" class="border-width" value="<?php echo $border_width; ?>">
				</td>
				<td>
					<select name="pm_vat_options[border_style]" id="border_style" class="border-style">
						<option value="none" <?php selected( $border_style, 'none', true ); ?>>None</option>
						<option value="solid" <?php selected( $border_style, 'solid', true ); ?>>Solid</option>
						<option value="dashed" <?php selected( $border_style, 'dashed', true ); ?>>Dashed</option>
						<option value="dotted" <?php selected( $border_style, 'dotted', true ); ?>>Dotted</option>
						<option value="double" <?php selected( $border_style, 'double', true ); ?>>Double</option>
						<option value="groove" <?php selected( $border_style, 'groove', true ); ?>>Groove</option>
						<option value="ridge" <?php selected( $border_style, 'ridge', true ); ?>>Ridge</option>
						<option value="inset" <?php selected( $border_style, 'inset', true ); ?>>Inset</option>
						<option value="outset" <?php selected( $border_style, 'outset', true ); ?>>Outset</option>
					</select>
				</td>
			</tr>
		</tbody>
	</table>
	<?php
}
function pm_vat_background_field_callback() {
	$pm_vat_opts = get_option( 'pm_vat_options' );
	$background_color = ( empty( $pm_vat_opts['stylearray']['background_color'] ) ) ? '' : stripslashes( $pm_vat_opts['stylearray']['background_color'] ) ;
	?>
	<input type="text" name="pm_vat_options[background_color]" id="background_color" class="color-picker" value="<?php echo $background_color; ?>">
	<?php
}
function pm_vat_font_field_callback() {
	$pm_vat_opts = get_option( 'pm_vat_options' );
	$font_color = ( empty( $pm_vat_opts['stylearray']['font_color'] ) ) ? '' : stripslashes( $pm_vat_opts['stylearray']['font_color'] ) ;
	$font_size = ( empty( $pm_vat_opts['stylearray']['font_size'] ) ) ? '' : stripslashes( $pm_vat_opts['stylearray']['font_size'] ) ;
	?>	
	<table id="font-options-table">
		<thead>
			<tr>
				<th>Font color</th>
				<th>Font size (pixels)</th>
			</tr>
		</thead>
		<tbody>
			<tr>
				<td>
					<input type="text" name="pm_vat_options[font_color]" id="font_color" class="color-picker" value="<?php echo $font_color; ?>">
				</td>
				<td>
					<input type="text" name="pm_vat_options[font_size]" id="font_size" class="font-size" value="<?php echo $font_size; ?>">
				</td>
			</tr>
		</tbody>
	</table>
	<?php
}
function pm_vat_optsdata_field_callback() {
	// Be sure the field names are formatted for array!
	// Also be sure name does not have ''
	$pm_vat_opts = get_option( 'pm_vat_options' );
	$del_opt_settings = ( empty( $pm_vat_opts['del_opt_settings'] ) ) ? '' : $pm_vat_opts['del_opt_settings'];
	?>
	<input type="checkbox" name="pm_vat_options[del_opt_settings]" value="1" id="del_opt_settings" <?php checked( $del_opt_settings, '1', true ); ?>> <label for="del_opt_settings">Yes. Delete all settings data when I uninstall</label><br>
	<small>Use with caution! When checked, all settings will be deleted on plugin uninstall. Disabling will not delete data only uninstall.</small>
	<?php
}

// Validate options
function pm_vat_validate_options( $input ) {
	$pm_vat_options = get_option( 'pm_vat_options' );
	$valid_input = $pm_vat_options;

	// Determine which tab is submitted
	$videos = ( !empty( $input['submit-ads'] ) ? true : false );
	$misc = ( !empty( $input['submit-misc'] ) ? true : false );
	$adstyle = ( !empty( $input['submit-adstyle'] ) ? true : false );

	if( $videos ) {
		// validate only those settings
		$videos = ( empty( $input['videos'] ) ) ? '' : $input['videos'] ;
		// Check to see if data is array as expected
		if( is_array( $videos ) ) {
			// Loop through & validate each setting
			foreach ($videos as $video_key => $video) {
				$valid_video_input[$video_key]['videoname'] = ( isset( $video['videoname'] ) ) ? wp_kses_post( $video['videoname'] ) : '' ;
				$valid_video_input[$video_key]['ytvdoid'] = ( isset( $video['ytvdoid'] ) ) ? sanitize_text_field( $video['ytvdoid'] ) : '' ;
				$valid_video_input[$video_key]['pausetext'] = ( isset( $video['pausetext'] ) ) ? wp_kses_post( $video['pausetext'] ) : '' ;
				$valid_video_input[$video_key]['endtext'] = ( isset( $video['endtext'] ) ) ? wp_kses_post( $video['endtext'] ) : '' ;
				$valid_video_input[$video_key]['endscreen'] = ( isset( $video['endscreen'] ) ) ? wp_kses_post( $video['endscreen'] ) : '' ;
				$valid_video_input[$video_key]['controls'] = ( isset( $video['controls'] ) && $video['controls'] == '2' ) ? '2' : '0' ;
				$valid_video_input[$video_key]['autoplay'] = ( isset( $video['autoplay'] ) && $video['autoplay'] == '1' ) ? '1' : '0' ;
				$valid_video_input[$video_key]['focusplay'] = ( isset( $video['focusplay'] ) && $video['focusplay'] == '1' ) ? '1' : '0' ;

				// Remove last item of array (clone field template always empty)
				array_pop( $video['messages']['adtext'] );
				// Now count how many items in array
				$message_count = count($video['messages']['adtext']);
				// Then show them
				for( $i = 0; $i < $message_count; $i++ ) {				
					$valid_video_input[$video_key]['messages'][$i]['adtext'] = ( isset( $video['messages']['adtext'][$i] ) ) ? wp_kses_post( $video['messages']['adtext'][$i] ) : '' ;
					$valid_video_input[$video_key]['messages'][$i]['fromtime'] = ( isset( $video['messages']['fromtime'][$i] ) && is_numeric( $video['messages']['fromtime'][$i] ) ) ? sanitize_text_field( $video['messages']['fromtime'][$i] ) : '' ;
					$valid_video_input[$video_key]['messages'][$i]['totime'] = ( isset( $video['messages']['totime'][$i] ) && is_numeric( $video['messages']['totime'][$i] ) ) ? sanitize_text_field( $video['messages']['totime'][$i] ) : '' ;
				}
			}
		} else {
			$valid_video_input = array();
		}

		// Build array to save to option
		$valid_input = array(
			'videos' => $valid_video_input,
			'stylearray' => $pm_vat_options['stylearray'],
			'del_opt_settings' => $pm_vat_options['del_opt_settings'],
			);

	} elseif ( $misc ) {
		// validate only those settings
		$valid_del_opt_settings = ( isset( $input['del_opt_settings'] ) && $input['del_opt_settings'] == 1 ) ? 1 : 0 ;

		// Build array to save to option
		$valid_input = array(
			'videos' => $pm_vat_options['videos'],
			'stylearray' => $pm_vat_options['stylearray'],
			'del_opt_settings' => $valid_del_opt_settings,
			);
	} elseif ( $adstyle ) {
		// validate only those settings
		$valid_stylearray['border_color'] = ( isset( $input['border_color'] ) && ( preg_match( '/^#[a-f0-9]{6}$/i', $input['border_color'] ) == '1' ) ) ? sanitize_text_field( $input['border_color'] ) : '' ;
		$valid_stylearray['border_width'] = ( isset( $input['border_width'] ) && is_numeric( $input['border_width'] ) ) ? sanitize_text_field( $input['border_width'] ) : '' ;
		$border_style_array = array('none', 'solid', 'dashed', 'dotted', 'double', 'groove', 'ridge', 'inset', 'outset');
		$valid_stylearray['border_style'] = ( isset( $input['border_style'] ) && in_array( $input['border_style'], $border_style_array ) ) ? sanitize_text_field( $input['border_style'] ) : '' ;
		$valid_stylearray['background_color'] = ( isset( $input['background_color'] ) && ( preg_match( '/^#[a-f0-9]{6}$/i', $input['background_color'] ) == '1' ) ) ? sanitize_text_field( $input['background_color'] ) : '' ;
		$valid_stylearray['font_color'] = ( isset( $input['font_color'] ) && ( preg_match( '/^#[a-f0-9]{6}$/i', $input['font_color'] ) == '1' ) ) ? sanitize_text_field( $input['font_color'] ) : '' ;
		$valid_stylearray['font_size'] = ( isset( $input['font_size'] ) && is_numeric( $input['font_size'] ) ) ? sanitize_text_field( $input['font_size'] ) : '' ;

		// Build array to save to option
		$valid_input = array(
			'videos' => $pm_vat_options['videos'],
			'stylearray' => $valid_stylearray,
			'del_opt_settings' => $pm_vat_options['del_opt_settings'],
			);
	}
	return $valid_input;
	//print_r($valid_input);
	//exit();
}
?>